@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 #include <gtk/gtk.h>
 #include <cspi/spi.h>
 #include <libbonobo.h>
@@ -195,7 +196,6 @@ test_desktop (void)
 {
 	Accessible  *desktop;
 	Accessible  *application;
-	int          length;
 	Accessible **list;
 
 	fprintf (stderr, "Testing desktop...\n");
@@ -204,7 +204,7 @@ test_desktop (void)
 	desktop = SPI_getDesktop (0);
 	g_assert (desktop != NULL);
 
-	g_assert ((length = SPI_getDesktopList (&list)) > 0);
+	g_assert ((SPI_getDesktopList (&list)) > 0);
 	g_assert (list[0] == desktop);
 	SPI_freeDesktopList (list);
 
@@ -233,6 +233,10 @@ test_application (Accessible *application)
 	g_assert (!strcmp (str, "GAIL"));
 	SPI_freeString (str);
 
+	str = AccessibleApplication_getLocale (application, LC_MESSAGES);
+	g_assert (!strcmp (str, setlocale (LC_MESSAGES, NULL)));
+        SPI_freeString (str);
+
 	str = AccessibleApplication_getVersion (application);
 	g_assert (str != NULL);
 	SPI_freeString (str);
@@ -686,12 +690,13 @@ key_listener_cb (const AccessibleKeystroke *stroke,
 	AccessibleKeystroke *s = user_data;
 	
 	*s = *stroke;
+	if (stroke->keystring) s->keystring = g_strdup (stroke->keystring);
 	
 	if (s->type == SPI_KEY_PRESSED)
 		key_press_received = TRUE;
 	else if (s->type == SPI_KEY_RELEASED)
 		key_release_received = TRUE;
-	
+
 	return TRUE;
 }
 
@@ -723,11 +728,11 @@ test_keylisteners (void)
 		g_assert (SPI_generateKeyboardEvent ('=', NULL, SPI_KEY_SYM));
 		while (!(key_press_received))
 			g_main_context_iteration (NULL, TRUE);
-		fprintf (stderr, "p");
+		fprintf (stderr, "p [%s]", stroke.keystring);
 	        g_assert (!strcmp (stroke.keystring, "="));
 		while (!(key_release_received))
 			g_main_context_iteration (NULL, TRUE);
-		fprintf (stderr, "r ");
+		fprintf (stderr, "r [%s]", stroke.keystring);
 		key_press_received = FALSE;
 		key_release_received = FALSE;
 	}
